require "numru/advanceddcl"

include NumRu::AdvancedDCL

nx1 = 21
nx2 = 5
ny1 = 0
ny2 = 18

rx1 = [-50, -45, -40, -35, -30, -25, -20, -15, -10, -5, 0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50]
rx2 = [-40, -20, 0, 20, 40]
cx2 = ["40S ", "20S ", "EQ  ", "20N ", "40N "]
ry2 = [1000, 850, 700, 500, 400, 300, 250, 200, 150, 100, 70, 50, 30, 10, 5, 2, 1, 0.4]
cy2 = ["1000", "    ", "    ", "500 ", "    ", "    ", "    ", "200 ", "    ", "100 ", "    ", "50  ", "30  ", "10  ", "5   ", "2   ", "1   ", ".4  "]
dummy =[]
  
Dev.open("X")
Frame.new

Fig.set("window", [-50.0, 50.0, 1.0e3, 0.4])
Fig.set("viewport", [0.2, 0.8, 0.2, 0.8])
Fig.set("transnum", 2)

Axis::Lin.xaxlb("B", rx1, rx2, cx2)
Axis::Lin.xaxlb("T", rx1, rx2, cx2)
Axis::Lin.xsttl("B", "LATITUDE", 0.0)

Axis::Lin.yaxlb("L", dummy, ry2, cy2)
Axis::Lin.yaxlb("R", dummy, ry2, cy2)
Axis::Lin.ysttl("L", "PRESSURE", 0.0)

Axis::Lin.xmttl("T", "UXAXLB/UYAXLB", 0.0)

Dev.close
